==> gc_board_0.08.06.tar.gz: gc_board_0.08.06/include/gc_lib.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// gc_lib.php
//  ⺻ Լ 
// 2005. 6. 5.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// Database ϴ Լ
//
// return  : ͺ̽  link identifier
///////////////////////////////////////////////////////////////////////////
function db_connect()
{
	// DB  ִ  ´.
	// 
	//   ̸					: con_info[1]
	//     ̸		: con_info[2]
	//    н			: con_info[3]
	// gc_board ġǾ ִ DB̸	: con_info[4]
	if (!file_exists("../config/db_info.php"))
		out_error(" ϴ.");
	$info_view = file_get_contents("../config/db_info.php");
	$con_info = explode(" ", $info_view);
	
	$connect = @mysql_connect($con_info[1], $con_info[2], $con_info[3])
			or out_error("ͺ̽   ϴ.");
	@mysql_select_db($con_info[4])
			or out_error("ͺ̽   ϴ.");
	
	return $connect;
}

///////////////////////////////////////////////////////////////////////////
// gc_board ⺻   о Լ
//
// return : ⺻  迭
///////////////////////////////////////////////////////////////////////////
function get_basic_config()
{
	global $connect;

	$basic_config_query = "select * from gc_basic_config";
	$basic_config_row = gc_query($basic_config_query);

	// ⺻   ġ ̻  
	if ($basic_config_row == 0)
		out_error("Խ ġ  ֽϴ.");

	return $basic_config_row[0];
}

///////////////////////////////////////////////////////////////////////////
// html (ø ) о Լ
//
// remake_link ϱ  frame    ǰ ʿϴ.
//
// link		: о  
// type		: о  	NULL : ø
//									html : ø  html 
//
// return : string ȯ  
///////////////////////////////////////////////////////////////////////////
function loadfile($link, $type="")
{
	if(!($buffer = @file_get_contents($link)))
		out_error($link."    ϴ.");

	$file_dir = explode("/", $link);
	$file_dir = ereg_replace("/".$file_dir[(sizeof($file_dir)-1)]."$"
			, "", $link);

	// Ų ִ ̹  ũ ¿ ° 
	if (empty($type))
	{
		$buffer = eregi_replace("(src=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(background=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(link href=\"?)", "\\1".$file_dir."/"
			, $buffer);
	}
	else if ($type == "html")
	{
		$buffer = eregi_replace("(src=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(background=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(href=\"?)", "\\1".$file_dir."/"
			, $buffer);
	}

	return $buffer;
}

///////////////////////////////////////////////////////////////////////////
// ⺻ Error ó Լ
//
// msg		:  ޼
// url		:  ߻  ũ 
//
// return : 
///////////////////////////////////////////////////////////////////////////
function out_error($msg, $url="javascript:history.back();")
{
	global $skinname, $top_file, $bottom_file;

	$skin_link = $skinname."/error.htm";

	// Ų  ⺻ admin/skin/default 
	if (empty($skinname) || !file_exists($skin_link))
	{
		$skin_link = "../admin/skin/default/error.htm";
		// admin/skin/default Ų  ġ  ޼ 
		if (!file_exists($skin_link))
		{
			echo "/admin/skin/default/error.htm  ã  ϴ.<br>"
				."ġ    ϴ.<br><br>".$msg;
			exit;
		}
	}

	$error_view = loadfile($skin_link);
	$error_view = str_replace("<#޼>",$msg,$error_view);
	$error_view = str_replace("<#Ȯΰ>",$url,$error_view);

	print_all($top_file, $bottom_file, $error_view);

	exit;
}

///////////////////////////////////////////////////////////////////////////
// query ó κ ϰ ִ Լ
//
// query	: ó Query
//
// return : insert, update  true  ȯ
// 			select  ˻  2 array · ȯ
///////////////////////////////////////////////////////////////////////////
function gc_query($query)
{
	global $connect;
	
	if (!($result = mysql_query($query)))
		out_error(" ߽ϴ.<br>".$query."<br>".mysql_error());

	// insert, update  query  
	if ($result == 1)
		return true;

	// select  query  
	$total_row = array();
	while ($row = mysql_fetch_array($result))
		array_push($total_row, $row);

	// select    
	if ($total_row[0] == false)
		return 0;

	return $total_row;
}

///////////////////////////////////////////////////////////////////////////
//   θ  Լ
//
// link		: θ  ϴ 
//
// return :  
///////////////////////////////////////////////////////////////////////////
function get_link($link)
{
}

///////////////////////////////////////////////////////////////////////////
//  ۾ ģ ҽ  ϴ Լ
//
// top_file		: ʿ   .    
// bottom_file	: Ʒʿ   .    
// main_view	:   (string ).  ۾ ģ ҽ
// back_file	: Խ µ κ(board_tag) Ե 
//				(: <#Խ> Ե )    
// board_tag	: Խ µ κ Ÿ ±(: <#Խ>)
//
// return 	: 
///////////////////////////////////////////////////////////////////////////
function print_all($top_file="", $bottom_file="", $main_view
		, $back_file="", $board_tag="")
{
	///////////////////////////////////////////////////////////////////////
	//   ؼ     θ Լ ȿ
	// ٽ 
	//
	// ̰ ̹   ٽ θ  Ͽ 
	//      Լ ο ٽ include
	//    ϱ  
	///////////////////////////////////////////////////////////////////////
	while (list($key, $val) = each($GLOBALS))
		$$key = $val;

	// top_file о κ
	if (!empty($top_file) and file_exists($top_file))
	{
		$top_view = loadfile($top_file, "html");
		echo $top_view;
	}

	// main_view 
	if (!empty($back_file) and !empty($board_tag) and file_exists($back_file))
	{
		$back_view = loadfile($back_file, "html");
		$main_view = str_replace($board_tag, $main_view, $back_view);
	}
	echo "\n".$main_view."\n";

	// bottom_file о κ
	if (!empty($bottom_file) and file_exists($bottom_file))
	{
		$bottom_view = loadfile($bottom_file, "html");
		echo $bottom_view;
	}
}

///////////////////////////////////////////////////////////////////////////
// 丮 ϴ Լ (׻ 0777 Ѵ.)
//
// dir_name	:   丮 θ
//
// return : 
///////////////////////////////////////////////////////////////////////////
function make_dir($dir_name)
{
	if (is_dir($dir_name))
		out_error("̹  ̸ 丮 մϴ.");
	if (!mkdir($dir_name, 0777))
		out_error("ʿ 丮  Ͽϴ.<br>"
			." 丮 㰡 Ⱑ ϰ ֽʽÿ.");
}

///////////////////////////////////////////////////////////////////////////
// 丮 ϴ Լ
//
// dir_name	:   丮 θ
//
// return : 
///////////////////////////////////////////////////////////////////////////
function del_dir($dir_name)
{
	// 丮   .
	if (!($dp = opendir($dir_name)))
		out_error($dir_name." 丮 ų б ϴ.");
	while ($file_name = readdir($dp))
	{
		if (($file_name != ".") and ($file_name != ".."))
		{
			if (is_dir($dir_name."/".$file_name))
				del_dir($dir_name."/".$file_name);
			else
				unlink($dir_name."/".$file_name);
		}
	}
	closedir($dp);

	// 丮 .
	if (!rmdir($dir_name))
		out_error($dir_name." 丮  Ͽϴ.<br>"
			." 丮 㰡 Ⱑ ϰ ֽʽÿ.");	
}

///////////////////////////////////////////////////////////////////////////
// ǥĿ شϴ ڿ 迭  Լ
//
// pattern		: ǥ
// original_str	: ãƾ  Ǵ ڿ
//
// return 	: pattern ġϴ ڵ ڿ
///////////////////////////////////////////////////////////////////////////
function get_all_pattern($pattern, $original_str)
{
}

///////////////////////////////////////////////////////////////////////////
// α ó Լ
//
// id		: αϰ ϴ ̵
// passwd	: α  н
//
// return : 
///////////////////////////////////////////////////////////////////////////
function login($id, $passwd)
{
	global $connect;

	// ̵ н尡  翬 α 
	if (empty($id) or empty($passwd))
		return out_error("ID Password ߸Ǿϴ.");

	$chk_query = "select * from gc_member where member_id='$id' "
			."and passwd=password('$passwd')";
	$chk_row = gc_query($chk_query);
	if ($chk_row == 0)
		return out_error("ID Password ߸Ǿϴ.");
	$chk_row = $chk_row[0];

	//   α ̹Ƿ  Ѵ.
	session_destroy();
	session_start();
	session_register("sesLOGINTIME", "sesID", "sesLEVEL");
	$GLOBALS["sesLOGINTIME"] = time();
	$GLOBALS["sesID"] = $id;
	$GLOBALS["sesLEVEL"] = $chk_row["level"];

	//  α ð 
}

///////////////////////////////////////////////////////////////////////////
// α׾ƿ ó Լ
//
// return : 
///////////////////////////////////////////////////////////////////////////
function logout()
{
	session_destroy();
}

///////////////////////////////////////////////////////////////////////////
// α Ȯ Լ
//
// return : α Ǿ  true, ƴϸ false;
///////////////////////////////////////////////////////////////////////////
function chk_login()
{
	global $sesLOGINTIME;

	if (!isset($sesLOGINTIME) or empty($sesLOGINTIME))
		return false;
	else
		return true;
}

///////////////////////////////////////////////////////////////////////////
// ũŸκ   ϴ Լ
//
// tblname		:  üũϱ ̺
// field_name	:  üũϱ ʵ
//
// return 	: ũŸκ  ڿ
///////////////////////////////////////////////////////////////////////////
function get_unique_str($tblname="", $field_name="")
{
	$unique_str = microtime();
	$unique_str = str_replace(" ", "_", $unique_str);
	$unique_str = str_replace(".", "", $unique_str);

	// $table_name̳ $field_name  쿡 ̺ ˻ Ѵ.	
	if (($table_name != "") || ($field_name != ""))
		return $unique_str;

	// ش ̺ ߺ ʴ    ˻
	for ($i=0; ; $i++)
	{
		$chk_query = "select count(*) from $tblname"
				." where $field_name='$unique_str'";
		$chk_row = gc_query($chk_query);
		if($chk_row[0][0] == 0) break;
		$unique_str .= "_".$i;
	}
	return $unique_str;
}

///////////////////////////////////////////////////////////////////////////
//  Ȯڸ  Լ
//
// file_name	: Ȯڸ    ̸
//
// return 	: Ȯ
///////////////////////////////////////////////////////////////////////////
function get_ext($file_name)
{
	$temp_ext = explode(".", $file_name);
	return $temp_ext[(sizeof($temp_ext)-1)];
}

///////////////////////////////////////////////////////////////////////////
//  ϴ Լ
//
// temp_file	: ӽ÷  ö  ü  (̸ )
// save_dir		: ϰ ϴ 丮
// new_name		: ο ̸ (  ũŸӰ )
// size			:   Ѱ뷮 (K:ųιƮ, M:ްƮ)
// tblname		:  ̸  ̺
// field_name	:  ̸  ʵ
//
// return 	:   ü  (̸ )
//					($save_dir . "/" . $new_name)
///////////////////////////////////////////////////////////////////////////
function save_file($temp_file, $save_dir, $new_name="", $size=""
	, $tblname="", $field_name="")
{
	// ʿ  Ȯ
	if (($temp_file == "") || !file_exists($temp_file))
		out_error("   ϴ.");
	//  ġ Ȯ
	if (($save_dir == "") || !file_exists($save_dir))
		out_error(" ġ ùٸ ʽϴ.");
	// 뷮 Ѱ Ȯ
	if (!empty($size))
	{
		// ųιƮ
		if (strtoupper(substr($size,-1)) == "K")
		{
			$temp_byte = substr($size, 0, strlen($size)-1);
			$temp_byte = $temp_byte*1024;
		}
		// ްƮ
		else if (strtoupper(substr($size,-1)) == "M")
		{
			$temp_byte = substr($size, 0, strlen($size)-1);
			$temp_byte = $temp_byte*1024*1024;
		}

		// 뷮 Ȯ
		if ($temp_byte < filesize($temp_file))
			out_error(" 뷮 ʰϿϴ.");
	}

	//   ̸    
	if ($new_name == "")
		$new_name = get_unique_str($tblname, $field_name);
	if (!ereg("/$", $save_dir))
		$save_dir .= "/";

	//  
	$new_file = $save_dir . $new_name;
	if(!copy($temp_file, $new_file))
		out_error(" 翡  ߽ϴ.");
	return $new_file;
}

///////////////////////////////////////////////////////////////////////////
//  
//
// ̰   κ ־ α      ʿ䰡
// .
//
// no_session  Ȱȭ Ǿ    ʴ´.
// ̴ ġ  ʿϴ.
///////////////////////////////////////////////////////////////////////////
if (!isset($no_session) or ($no_session != true))
	session_start();

///////////////////////////////////////////////////////////////////////////
// SQL 
//
// ̰ SQL ϴ κ  ν gc_lib.php ϸ DB
//  ڵ Ѵ.
///////////////////////////////////////////////////////////////////////////
$connect = db_connect();

///////////////////////////////////////////////////////////////////////////
// ⺻    κ
//
// ⼭   gc_board  ҿ ȴ.
///////////////////////////////////////////////////////////////////////////
$basic_config_row = get_basic_config();

$admin_skin		= $basic_config_row["admin_skin"];	//  Ų
$main_skin		= $basic_config_row["main_skin"];	//  Ų
$member_skin	= $basic_config_row["member_skin"];	//  Ų

$admin_top_file		= $basic_config_row["admin_top_file"];	  //  top_file
$admin_bottom_file	= $basic_config_row["admin_bottom_file"]; //  top_file
?>

==> gc_board_0.09.00.tar.gz: gc_board_0.09.00/include/gc_lib.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// gc_lib.php
//  ⺻ Լ 
// 2005. 7. 19.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// Database ϴ Լ
//
// return  : ͺ̽  link identifier
///////////////////////////////////////////////////////////////////////////
function db_connect()
{
	// DB  ִ  ´.
	// 
	//   ̸					: con_info[1]
	//     ̸		: con_info[2]
	//    н			: con_info[3]
	// gc_board ġǾ ִ DB̸	: con_info[4]
	if (!file_exists("../config/db_info.php"))
		out_error(" ϴ.");
	$info_view = file_get_contents("../config/db_info.php");
	$con_info = explode(" ", $info_view);
	
	$connect = @mysql_connect($con_info[1], $con_info[2], $con_info[3])
			or out_error("ͺ̽   ϴ.");
	@mysql_select_db($con_info[4])
			or out_error("ͺ̽   ϴ.");
	
	return $connect;
}

///////////////////////////////////////////////////////////////////////////
// gc_board ⺻   о Լ
//
// return : ⺻  迭
///////////////////////////////////////////////////////////////////////////
function get_basic_config()
{
	global $connect;

	$basic_config_query = "select * from gc_basic_config";
	$basic_config_row = gc_query($basic_config_query);

	// ⺻   ġ ̻  
	if ($basic_config_row == 0)
		out_error("Խ ġ  ֽϴ.");

	return $basic_config_row[0];
}

///////////////////////////////////////////////////////////////////////////
// html (ø ) о Լ
//
// remake_link ϱ  frame    ǰ ʿϴ.
//
// link		: о  
// type		: о  	NULL : ø
//									html : ø  html 
//
// return : string ȯ  
///////////////////////////////////////////////////////////////////////////
function loadfile($link, $type="")
{
	if(!($buffer = @file_get_contents($link)))
		out_error($link."    ϴ.");

	$file_dir = explode("/", $link);
	$file_dir = ereg_replace("/".$file_dir[(sizeof($file_dir)-1)]."$"
			, "", $link);

	// Ų ִ ̹  ũ ¿ ° 
	if (empty($type))
	{
		$buffer = eregi_replace("(src=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(background=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(link href=\"?)", "\\1".$file_dir."/"
			, $buffer);
	}
	else if ($type == "html")
	{
		$buffer = eregi_replace("(src=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(background=\"?)", "\\1".$file_dir."/"
			, $buffer);
		$buffer = eregi_replace("(href=\"?)", "\\1".$file_dir."/"
			, $buffer);
	}

	return $buffer;
}

///////////////////////////////////////////////////////////////////////////
// ⺻ Error ó Լ
//
// msg		:  ޼
// url		:  ߻  ũ 
//
// return : 
///////////////////////////////////////////////////////////////////////////
function out_error($msg, $url="javascript:history.back();")
{
	global $skinname, $top_file, $bottom_file;

	$skin_link = $skinname."/error.htm";

	// Ų  ⺻ admin/skin/default 
	if (empty($skinname) || !file_exists($skin_link))
	{
		$skin_link = "../admin/skin/default/error.htm";
		// admin/skin/default Ų  ġ  ޼ 
		if (!file_exists($skin_link))
		{
			echo "/admin/skin/default/error.htm  ã  ϴ.<br>"
				."ġ    ϴ.<br><br>".$msg;
			exit;
		}
	}

	$error_view = loadfile($skin_link);
	$error_view = str_replace("<#޼>",$msg,$error_view);
	$error_view = str_replace("<#Ȯΰ>",$url,$error_view);

	print_all($top_file, $bottom_file, $error_view);

	exit;
}

///////////////////////////////////////////////////////////////////////////
// query ó κ ϰ ִ Լ
//
// query	: ó Query
//
// return : insert, update  true  ȯ
// 			select  ˻  2 array · ȯ
///////////////////////////////////////////////////////////////////////////
function gc_query($query)
{
	global $connect;
	
	if (!($result = mysql_query($query)))
		out_error(" ߽ϴ.<br>".$query."<br>".mysql_error());

	// insert, update  query  
	if ($result == 1)
		return true;

	// select  query  
	$total_row = array();
	while ($row = mysql_fetch_array($result))
		array_push($total_row, $row);

	// select    
	if ($total_row[0] == false)
		return false;

	return $total_row;
}

///////////////////////////////////////////////////////////////////////////
//   θ  Լ
//
// link		: θ  ϴ 
//
// return :  
///////////////////////////////////////////////////////////////////////////
function get_link($link)
{
}

///////////////////////////////////////////////////////////////////////////
//  ۾ ģ ҽ  ϴ Լ
//
// top_file		: ʿ   .    
// bottom_file	: Ʒʿ   .    
// main_view	:   (string ).  ۾ ģ ҽ
// back_file	: Խ µ κ(board_tag) Ե 
//				(: <#Խ> Ե )    
// board_tag	: Խ µ κ Ÿ ±(: <#Խ>)
//
// return 	: 
///////////////////////////////////////////////////////////////////////////
function print_all($top_file="", $bottom_file="", $main_view
		, $back_file="", $board_tag="")
{
	///////////////////////////////////////////////////////////////////////
	//   ؼ     θ Լ ȿ
	// ٽ 
	//
	// ̰ ̹   ٽ θ  Ͽ 
	//      Լ ο ٽ include
	//    ϱ  
	///////////////////////////////////////////////////////////////////////
	while (list($key, $val) = each($GLOBALS))
		$$key = $val;

	// top_file о κ
	if (!empty($top_file) and file_exists($top_file))
	{
		$top_view = loadfile($top_file, "html");
		echo $top_view;
	}

	// main_view 
	if (!empty($back_file) and !empty($board_tag) and file_exists($back_file))
	{
		$back_view = loadfile($back_file, "html");
		$main_view = str_replace($board_tag, $main_view, $back_view);
	}
	echo "\n".$main_view."\n";

	// bottom_file о κ
	if (!empty($bottom_file) and file_exists($bottom_file))
	{
		$bottom_view = loadfile($bottom_file, "html");
		echo $bottom_view;
	}
}

///////////////////////////////////////////////////////////////////////////
// 丮 ϴ Լ (׻ 0777 Ѵ.)
//
// dir_name	:   丮 θ
//
// return : 
///////////////////////////////////////////////////////////////////////////
function make_dir($dir_name)
{
	if (@is_dir($dir_name))
		out_error("̹  ̸ 丮 մϴ.");
	if (!@mkdir($dir_name, 0777))
		out_error("ʿ 丮  Ͽϴ.<br>"
			." 丮 㰡 Ⱑ ϰ ֽʽÿ.");
}

///////////////////////////////////////////////////////////////////////////
// 丮 ϴ Լ
//
// dir_name	:   丮 θ
//
// return : 
///////////////////////////////////////////////////////////////////////////
function del_dir($dir_name)
{
	// 丮   .
	if (!($dp = opendir($dir_name)))
		out_error($dir_name." 丮 ų б ϴ.");
	while ($file_name = readdir($dp))
	{
		if (($file_name != ".") and ($file_name != ".."))
		{
			if (is_dir($dir_name."/".$file_name))
				del_dir($dir_name."/".$file_name);
			else
				unlink($dir_name."/".$file_name);
		}
	}
	closedir($dp);

	// 丮 .
	if (!rmdir($dir_name))
		out_error($dir_name." 丮  Ͽϴ.<br>"
			." 丮 㰡 Ⱑ ϰ ֽʽÿ.");	
}

///////////////////////////////////////////////////////////////////////////
// ǥĿ شϴ ڿ 迭  Լ
//
// pattern		: ǥ
// original_str	: ãƾ  Ǵ ڿ
//
// return 	: pattern ġϴ ڵ ڿ
///////////////////////////////////////////////////////////////////////////
function get_all_pattern($pattern, $original_str)
{
}

///////////////////////////////////////////////////////////////////////////
// α ó Լ
//
// id		: αϰ ϴ ̵
// passwd	: α  н
//
// return : 
///////////////////////////////////////////////////////////////////////////
function login($id, $passwd)
{
	global $connect;

	// ̵ н尡  翬 α 
	if (empty($id) or empty($passwd))
		return out_error("ID Password ߸Ǿϴ.");

	$chk_query = "select * from gc_member where member_id='$id' "
			."and passwd=password('$passwd')";
	$chk_row = gc_query($chk_query);
	if ($chk_row == false)
		return out_error("ID Password ߸Ǿϴ.");
	$chk_row = $chk_row[0];

	//   α ̹Ƿ  Ѵ.
	session_destroy();
	session_start();
	session_register("sesLOGINTIME", "sesID", "sesLEVEL");
	$GLOBALS["sesLOGINTIME"] = time();
	$GLOBALS["sesID"] = $id;
	$GLOBALS["sesLEVEL"] = $chk_row["level"];

	//  α ð 
}

///////////////////////////////////////////////////////////////////////////
// α׾ƿ ó Լ
//
// return : 
///////////////////////////////////////////////////////////////////////////
function logout()
{
	session_destroy();
}

///////////////////////////////////////////////////////////////////////////
// α Ȯ Լ
//
// return : α Ǿ  true, ƴϸ false;
///////////////////////////////////////////////////////////////////////////
function chk_login()
{
	global $sesLOGINTIME;

	if (!isset($sesLOGINTIME) or empty($sesLOGINTIME))
		return false;
	else
		return true;
}

///////////////////////////////////////////////////////////////////////////
// ũŸκ   ϴ Լ
//
// tblname		:  üũϱ ̺
// field_name	:  üũϱ ʵ
//
// return 	: ũŸκ  ڿ
///////////////////////////////////////////////////////////////////////////
function get_unique_str($tblname="", $field_name="")
{
	$unique_str = microtime();
	$unique_str = str_replace(" ", "_", $unique_str);
	$unique_str = str_replace(".", "", $unique_str);

	// $table_name̳ $field_name  쿡 ̺ ˻ Ѵ.	
	if (($table_name != "") || ($field_name != ""))
		return $unique_str;

	// ش ̺ ߺ ʴ    ˻
	for ($i=0; ; $i++)
	{
		$chk_query = "select count(*) from $tblname"
				." where $field_name='$unique_str'";
		$chk_row = gc_query($chk_query);
		if($chk_row[0][0] == 0) break;
		$unique_str .= "_".$i;
	}
	return $unique_str;
}

///////////////////////////////////////////////////////////////////////////
//  Ȯڸ  Լ
//
// file_name	: Ȯڸ    ̸
//
// return 	: Ȯ
///////////////////////////////////////////////////////////////////////////
function get_ext($file_name)
{
	$temp_ext = explode(".", $file_name);
	return $temp_ext[(sizeof($temp_ext)-1)];
}

///////////////////////////////////////////////////////////////////////////
//  ϴ Լ
//
// temp_file	: ӽ÷  ö  ü  (̸ )
// save_dir		: ϰ ϴ 丮
// new_name		: ο ̸ (  ũŸӰ )
// size			:   Ѱ뷮 (K:ųιƮ, M:ްƮ)
// tblname		:  ̸  ̺
// field_name	:  ̸  ʵ
//
// return 	:   ü  (̸ )
//					($save_dir . "/" . $new_name)
///////////////////////////////////////////////////////////////////////////
function save_file($temp_file, $save_dir, $new_name="", $size=""
	, $tblname="", $field_name="")
{
	// ʿ  Ȯ
	if (($temp_file == "") || !file_exists($temp_file))
		out_error("   ϴ.");
	//  ġ Ȯ
	if (($save_dir == "") || !file_exists($save_dir))
		out_error(" ġ ùٸ ʽϴ.");
	// 뷮 Ѱ Ȯ
	if (!empty($size))
	{
		// ųιƮ
		if (strtoupper(substr($size,-1)) == "K")
		{
			$temp_byte = substr($size, 0, strlen($size)-1);
			$temp_byte = $temp_byte*1024;
		}
		// ްƮ
		else if (strtoupper(substr($size,-1)) == "M")
		{
			$temp_byte = substr($size, 0, strlen($size)-1);
			$temp_byte = $temp_byte*1024*1024;
		}

		// 뷮 Ȯ
		if ($temp_byte < filesize($temp_file))
			out_error(" 뷮 ʰϿϴ.");
	}

	//   ̸    
	if ($new_name == "")
		$new_name = get_unique_str($tblname, $field_name);
	if (!ereg("/$", $save_dir))
		$save_dir .= "/";

	//  
	$new_file = $save_dir . $new_name;
	if(!copy($temp_file, $new_file))
		out_error(" 翡  ߽ϴ.");
	return $new_file;
}

///////////////////////////////////////////////////////////////////////////
//  
//
// ̰   κ ־ α      ʿ䰡
// .
///////////////////////////////////////////////////////////////////////////
session_start();

///////////////////////////////////////////////////////////////////////////
// SQL 
//
// ̰ SQL ϴ κ  ν gc_lib.php ϸ DB
//  ڵ Ѵ.
///////////////////////////////////////////////////////////////////////////
$connect = db_connect();

///////////////////////////////////////////////////////////////////////////
// ⺻    κ
//
// ⼭   gc_board  ҿ ȴ.
///////////////////////////////////////////////////////////////////////////
$basic_config_row = get_basic_config();

$admin_skin		= $basic_config_row["admin_skin"];	//  Ų
$main_skin		= $basic_config_row["main_skin"];	//  Ų
$member_skin	= $basic_config_row["member_skin"];	//  Ų

$admin_top_file		= $basic_config_row["admin_top_file"];	  //  top_file
$admin_bottom_file	= $basic_config_row["admin_bottom_file"]; //  top_file

///////////////////////////////////////////////////////////////////////////
// register_globals  Off   GET̳ POST Ѿ  ȭ
// Ű κ
///////////////////////////////////////////////////////////////////////////
while (list($key, $val) = each($_GET))
	$$key = $val;
while (list($key, $val) = each($_POST))
	$$key = $val;
?>
